@@ -1,4 +1,8 @@
+from __future__ import absolute_import
+from __future__ import print_function
+
 import qt_backport as _qt_backport
+
 if _qt_backport.CURRENT_EMULATOR is not None:
     raise ImportError("qt_backport emulator already running: '%s'" % \
                       _qt_backport.CURRENT_EMULATOR)
